define('io.ox/core/extensions', {
    point: function () { return { extend: _.identity, map: _.identity }; },
    Baton: function (obj) { return obj.app; }
});
